function Error()

%% Parameter initialisation
param = GetDefaultParameters();

%% Chosen image
im = imread('002.png');
im = rgb2gray(im);
im = double(im);

[size_x, size_y] = size(im);
center_x = size_x/2 + .5;
center_y = size_y/2 + .5;


%% Gradient Computation
im_modif = InterpolateImage(im, param);
im_modif = ProcessImage(im_modif, param);
grad = ComputeGradient(im_modif, param);
grad = ProcessGradient(grad, param);

%% Mask initialisation
mask = InitializeMask(im, grad, param);

%% Gradient line computation

% lines = circle_lines(50);
% 
% % Display Lines
% DispGradientLines(im_modif, param, lines, grad);
% %hold on; quiver(grad(:,:,1), grad(:,:,2)); hold off;

% CIRCULAIRE
% SUSHI : RealGradient
grad = Make_circle_gradient( im );

space = 3:5:center_y-3;
norm_grad = 1;
grad = norm_grad * grad;

    param.computeline.method = 'cauchy';    param.display.linespec = '-b';
    param.computeline.time_step = 0.01;    
    error = error_curve_circle( space );
    print_tikz_error( error, sprintf('data/error_cauchy_1e-2_e%g.data',norm_grad) );
        
    param.computeline.method = 'cauchy';    param.display.linespec = '-y';
    param.computeline.time_step = 0.1;
    error = error_curve_circle( space );
    print_tikz_error( error, sprintf('data/error_cauchy_1e-1_e%g.data',norm_grad) );

    param.computeline.method = 'explicit-piecewise';    param.display.linespec = '-r';
        error = error_curve_circle( space );
    print_tikz_error( error, sprintf('data/error_piecewise_e%g.data',norm_grad) );
    
    param.computeline.method = 'runge-kutta-23';    param.display.linespec = '-m';
        error = error_curve_circle( space );
    print_tikz_error( error, sprintf('data/error_rungekutta23_e%g.data',norm_grad) );
    
    param.computeline.method = 'runge-kutta-45';    param.display.linespec = '-g';
    error = error_curve_circle( space );
    print_tikz_error( error, sprintf('data/error_rungejutta45_e%g.data',norm_grad) );
    


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Local function

    function lines = circle_lines(space)                             %#ok<DEFNU>
        lines = cell(size(10:space:center_y-10));
        k = 1;
        for radius = 10:space:center_y-10
            x_0 = [ center_x - radius; center_y ];
            line = ComputeLine(x_0, grad, mask, param);
            lines{k} = line;
            k = k+1;
        end
    end

    function error = error_line_circle( center, radius, line )
        line = line - repmat( center, 1, size(line, 2) );
        % Norme L1 vvv
        foo = abs(sqrt(line(1,:).^2 + line(2,:).^2) - radius);
        error = sum(foo) / length(foo);
    end

    function errors = error_curve_circle(space)
        errors = zeros(length(space),2);
        k = 1;
        for radius = space
            x_0 = [ center_x - radius; center_y ];
            line = ComputeLine(x_0, grad, mask, param);
            errors(k,1) = radius;
            errors(k,2) = error_line_circle( [center_x; center_y], radius, line );
            k = k+1;
        end
        fprintf('\n');
    end
end

%% Local Local functions

    
function foo()

    param.computeline.method = 'cauchy';
    param.display.linespec = '-b';
    param.computeline.time_step = 0.01;
    DispGradientLines(im, param);
    hold on;    h = plot([0], [0],  param.display.linespec);
    leg = {'Method : Cauchy, dt = 0.01'};    hold off;
    
    param.computeline.method = 'cauchy';
    param.display.linespec = '-y';
    param.computeline.time_step = 0.1;
    DispGradientLines(im, param);
    hold on;    h = [h, plot([0], [0],  param.display.linespec)];
    leg = [leg, 'Method : Cauchy, dt = 0.1'];    hold off;

    param.computeline.method = 'explicit-piecewise';
    param.display.linespec = '-r';
    DispGradientLines(im, param);
    hold on;    h = [h, plot([0], [0],  param.display.linespec)];
    leg = [leg, 'Method : Explicit Piecewise'];    hold off;
    
    param.computeline.method = 'runge-kutta-23';
    param.display.linespec = '-m';
    DispGradientLines(im, param);
    hold on;    h = [h, plot([0], [0],  param.display.linespec)];
    leg = [leg, 'Method : Runge-Kutta 2-3'];    hold off;
    
    param.computeline.method = 'runge-kutta-45';
    param.display.linespec = '-g';
    DispGradientLines(im, param);
    hold on;    h = [h, plot([0], [0],  param.display.linespec)];
    leg = [leg, 'Method : Runge-Kutta 4-5'];    hold off;

end

%

function print_tikz_error( error, nom )

    fileID = fopen(nom, 'w');
    for i = 1:size(error,1)
        fprintf(fileID, '%2.6f\t%2.6f\n', error(i,1), error(i,2));
    end
    fclose( fileID );

end